@@ -1,6 +1,6 @@
 ///////////////////////////////////////////////////////////////////////////
 //
-// Copyright (c) 2012-2017 DreamWorks Animation LLC
+// Copyright (c) 2012-2018 DreamWorks Animation LLC
 //
 // All rights reserved. This software is distributed under the
 // Mozilla Public License 2.0 ( http://www.mozilla.org/MPL/2.0/ )
@@ -37,6 +37,7 @@
 #include "Stencils.h"
 #include "Maps.h"
 #include "Transform.h"
+#include <cmath> // for std::sqrt()
 
 
 namespace openvdb {
@@ -554,10 +555,10 @@ struct ISCurl
 template<DDScheme DiffScheme2, DScheme DiffScheme1>
 struct ISMeanCurvature
 {
-    /// @brief random access version
-    /// @return true if the gradient is none-zero, in which case the
-    /// mean curvature is computed as two parts: @c alpha is the numerator in
-    /// @f$\nabla \cdot (\nabla \phi / |\nabla \phi|)@f$, and @c beta is @f$|\nabla \phi|@f$.
+    /// @brief Random access version
+    /// @return @c true if the gradient is nonzero, in which case the mean curvature
+    /// is returned in two parts, @a alpha and @a beta, where @a alpha is the numerator
+    /// in &nabla; &middot; (&nabla;&Phi; / |&nabla;&Phi;|) and @a beta is |&nabla;&Phi;|.
     template<typename Accessor>
     static bool result(const Accessor& grid, const Coord& ijk,
                        typename Accessor::ValueType& alpha,
@@ -592,10 +593,10 @@ struct ISMeanCurvature
         return true;
     }
 
-    /// @brief stencil access version
-    /// @return true if the gradient is none-zero, in which case the
-    /// mean curvature is computed as two parts: @c alpha is the numerator in
-    /// @f$\nabla \cdot (\nabla \phi / |\nabla \phi|)@f$, and @c beta is @f$|\nabla \phi|@f$.
+    /// @brief Stencil access version
+    /// @return @c true if the gradient is nonzero, in which case the mean curvature
+    /// is returned in two parts, @a alpha and @a beta, where @a alpha is the numerator
+    /// in &nabla; &middot; (&nabla;&Phi; / |&nabla;&Phi;|) and @a beta is |&nabla;&Phi;|.
     template<typename StencilT>
     static bool result(const StencilT& stencil,
                        typename StencilT::ValueType& alpha,
@@ -764,9 +765,14 @@ struct Gradient<ScaleMap, CD_2ND>
         using Vec3Type = typename internal::ReturnValue<Accessor>::Vec3Type;
 
         Vec3Type iGradient( ISGradient<CD_2NDT>::result(grid, ijk) );
-        return  Vec3Type(ValueType(iGradient[0] * map.getInvTwiceScale()[0]),
-                         ValueType(iGradient[1] * map.getInvTwiceScale()[1]),
-                         ValueType(iGradient[2] * map.getInvTwiceScale()[2]) );
+        OPENVDB_NO_TYPE_CONVERSION_WARNING_BEGIN
+        const auto gradient0 = iGradient[0] * map.getInvTwiceScale()[0];
+        const auto gradient1 = iGradient[1] * map.getInvTwiceScale()[1];
+        const auto gradient2 = iGradient[2] * map.getInvTwiceScale()[2];
+        OPENVDB_NO_TYPE_CONVERSION_WARNING_END
+        return  Vec3Type(ValueType(gradient0),
+                         ValueType(gradient1),
+                         ValueType(gradient2));
     }
 
     // stencil access version
@@ -778,9 +784,14 @@ struct Gradient<ScaleMap, CD_2ND>
         using Vec3Type = typename internal::ReturnValue<StencilT>::Vec3Type;
 
         Vec3Type iGradient( ISGradient<CD_2NDT>::result(stencil) );
-        return  Vec3Type(ValueType(iGradient[0] * map.getInvTwiceScale()[0]),
-                         ValueType(iGradient[1] * map.getInvTwiceScale()[1]),
-                         ValueType(iGradient[2] * map.getInvTwiceScale()[2]) );
+        OPENVDB_NO_TYPE_CONVERSION_WARNING_BEGIN
+        const auto gradient0 = iGradient[0] * map.getInvTwiceScale()[0];
+        const auto gradient1 = iGradient[1] * map.getInvTwiceScale()[1];
+        const auto gradient2 = iGradient[2] * map.getInvTwiceScale()[2];
+        OPENVDB_NO_TYPE_CONVERSION_WARNING_END
+        return  Vec3Type(ValueType(gradient0),
+                         ValueType(gradient1),
+                         ValueType(gradient2));
     }
 };
 
@@ -798,9 +809,14 @@ struct Gradient<ScaleTranslateMap, CD_2ND>
         using Vec3Type = typename internal::ReturnValue<Accessor>::Vec3Type;
 
         Vec3Type iGradient( ISGradient<CD_2NDT>::result(grid, ijk) );
-        return  Vec3Type(ValueType(iGradient[0] * map.getInvTwiceScale()[0]),
-                         ValueType(iGradient[1] * map.getInvTwiceScale()[1]),
-                         ValueType(iGradient[2] * map.getInvTwiceScale()[2]) );
+        OPENVDB_NO_TYPE_CONVERSION_WARNING_BEGIN
+        const auto gradient0 = iGradient[0] * map.getInvTwiceScale()[0];
+        const auto gradient1 = iGradient[1] * map.getInvTwiceScale()[1];
+        const auto gradient2 = iGradient[2] * map.getInvTwiceScale()[2];
+        OPENVDB_NO_TYPE_CONVERSION_WARNING_END
+        return  Vec3Type(ValueType(gradient0),
+                         ValueType(gradient1),
+                         ValueType(gradient2));
     }
 
     // Stencil access version
@@ -812,9 +828,14 @@ struct Gradient<ScaleTranslateMap, CD_2ND>
         using Vec3Type = typename internal::ReturnValue<StencilT>::Vec3Type;
 
         Vec3Type iGradient( ISGradient<CD_2NDT>::result(stencil) );
-        return  Vec3Type(ValueType(iGradient[0] * map.getInvTwiceScale()[0]),
-                         ValueType(iGradient[1] * map.getInvTwiceScale()[1]),
-                         ValueType(iGradient[2] * map.getInvTwiceScale()[2]) );
+        OPENVDB_NO_TYPE_CONVERSION_WARNING_BEGIN
+        const auto gradient0 = iGradient[0] * map.getInvTwiceScale()[0];
+        const auto gradient1 = iGradient[1] * map.getInvTwiceScale()[1];
+        const auto gradient2 = iGradient[2] * map.getInvTwiceScale()[2];
+        OPENVDB_NO_TYPE_CONVERSION_WARNING_END
+        return  Vec3Type(ValueType(gradient0),
+                         ValueType(gradient1),
+                         ValueType(gradient2));
     }
 };
 //@}
@@ -1595,8 +1616,11 @@ struct Laplacian<ScaleMap, DiffScheme>
         ValueType iddy = D2<DiffScheme>::inY(grid, ijk);
         ValueType iddz = D2<DiffScheme>::inZ(grid, ijk);
         const Vec3d& invScaleSqr = map.getInvScaleSqr();
+        OPENVDB_NO_TYPE_CONVERSION_WARNING_BEGIN
         // scale them by the appropriate 1/dx^2, 1/dy^2, 1/dz^2 and sum
-        return ValueType(iddx * invScaleSqr[0] + iddy * invScaleSqr[1] + iddz * invScaleSqr[2]);
+        const ValueType value = iddx * invScaleSqr[0] + iddy * invScaleSqr[1] + iddz * invScaleSqr[2];
+        OPENVDB_NO_TYPE_CONVERSION_WARNING_END
+        return value;
     }
 
     // stencil access version
@@ -1610,8 +1634,11 @@ struct Laplacian<ScaleMap, DiffScheme>
         ValueType iddy = D2<DiffScheme>::inY(stencil);
         ValueType iddz = D2<DiffScheme>::inZ(stencil);
         const Vec3d& invScaleSqr = map.getInvScaleSqr();
+        OPENVDB_NO_TYPE_CONVERSION_WARNING_BEGIN
         // scale them by the appropriate 1/dx^2, 1/dy^2, 1/dz^2 and sum
-        return ValueType(iddx * invScaleSqr[0] + iddy * invScaleSqr[1] + iddz * invScaleSqr[2]);
+        const ValueType value = iddx * invScaleSqr[0] + iddy * invScaleSqr[1] + iddz * invScaleSqr[2];
+        OPENVDB_NO_TYPE_CONVERSION_WARNING_END
+        return value;
     }
 };
 
@@ -1629,8 +1656,11 @@ struct Laplacian<ScaleTranslateMap, DiffScheme>
         ValueType iddy = D2<DiffScheme>::inY(grid, ijk);
         ValueType iddz = D2<DiffScheme>::inZ(grid, ijk);
         const Vec3d& invScaleSqr = map.getInvScaleSqr();
+        OPENVDB_NO_TYPE_CONVERSION_WARNING_BEGIN
         // scale them by the appropriate 1/dx^2, 1/dy^2, 1/dz^2 and sum
-        return ValueType(iddx * invScaleSqr[0] + iddy * invScaleSqr[1] + iddz * invScaleSqr[2]);
+        const ValueType value = iddx * invScaleSqr[0] + iddy * invScaleSqr[1] + iddz * invScaleSqr[2];
+        OPENVDB_NO_TYPE_CONVERSION_WARNING_END
+        return value;
     }
 
     // stencil access version
@@ -1643,8 +1673,11 @@ struct Laplacian<ScaleTranslateMap, DiffScheme>
         ValueType iddy = D2<DiffScheme>::inY(stencil);
         ValueType iddz = D2<DiffScheme>::inZ(stencil);
         const Vec3d& invScaleSqr = map.getInvScaleSqr();
+        OPENVDB_NO_TYPE_CONVERSION_WARNING_BEGIN
         // scale them by the appropriate 1/dx^2, 1/dy^2, 1/dz^2 and sum
-        return ValueType(iddx * invScaleSqr[0] + iddy * invScaleSqr[1] + iddz * invScaleSqr[2]);
+        const ValueType value = iddx * invScaleSqr[0] + iddy * invScaleSqr[1] + iddz * invScaleSqr[2];
+        OPENVDB_NO_TYPE_CONVERSION_WARNING_END
+        return value;
     }
 };
 
@@ -1745,15 +1778,16 @@ struct CPT_RANGE
 
 
 /// @brief Compute the mean curvature.
-/// @return the mean curvature in two parts: @c alpha is the numerator in
-/// @f$\nabla \cdot (\nabla \phi / |\nabla \phi|)@f$, and @c beta is @f$|\nabla \phi|@f$.
+/// @details The mean curvature is returned in two parts, @a alpha and @a beta,
+/// where @a alpha is the numerator in &nabla; &middot; (&nabla;&Phi; / |&nabla;&Phi;|)
+/// and @a beta is |&nabla;&Phi;|.
 template<typename MapType, DDScheme DiffScheme2, DScheme DiffScheme1>
 struct MeanCurvature
 {
-    /// @brief random access version
-    /// @return true if the gradient is none-zero, in which case the
-    /// mean curvature is computed as two parts: @c alpha is the numerator in
-    /// @f$\nabla \cdot (\nabla \phi / |\nabla \phi|)@f$, and @c beta is @f$|\nabla \phi|@f$.
+    /// @brief Random access version
+    /// @return @c true if the gradient is nonzero, in which case the mean curvature
+    /// is returned in two parts, @a alpha and @a beta, where @a alpha is the numerator
+    /// in &nabla; &middot; (&nabla;&Phi; / |&nabla;&Phi;|) and @a beta is |&nabla;&Phi;|.
     template<typename Accessor>
     static bool compute(const MapType& map, const Accessor& grid, const Coord& ijk,
                         double& alpha, double& beta)
@@ -1829,10 +1863,10 @@ struct MeanCurvature
                ValueType(alpha/(2. *math::Pow2(beta))) : 0;
     }
 
-    /// @brief stencil access version
-    /// @return true if the gradient is none-zero, in which case the
-    /// mean curvature is computed as two parts: @c alpha is the numerator in
-    /// @f$\nabla \cdot (\nabla \phi / |\nabla \phi|)@f$, and @c beta is @f$|\nabla \phi|@f$.
+    /// @brief Stencil access version
+    /// @return @c true if the gradient is nonzero, in which case the mean curvature
+    /// is returned in two parts, @a alpha and @a beta, where @a alpha is the numerator
+    /// in &nabla; &middot; (&nabla;&Phi; / |&nabla;&Phi;|) and @a beta is |&nabla;&Phi;|.
     template<typename StencilT>
     static bool compute(const MapType& map, const StencilT& stencil,
                         double& alpha, double& beta)
@@ -2118,6 +2152,6 @@ private:
 
 #endif // OPENVDB_MATH_OPERATORS_HAS_BEEN_INCLUDED
 
-// Copyright (c) 2012-2017 DreamWorks Animation LLC
+// Copyright (c) 2012-2018 DreamWorks Animation LLC
 // All rights reserved. This software is distributed under the
 // Mozilla Public License 2.0 ( http://www.mozilla.org/MPL/2.0/ )
