@@ -1,6 +1,6 @@
 ///////////////////////////////////////////////////////////////////////////
 //
-// Copyright (c) 2012-2017 DreamWorks Animation LLC
+// Copyright (c) 2012-2019 DreamWorks Animation LLC
 //
 // All rights reserved. This software is distributed under the
 // Mozilla Public License 2.0 ( http://www.mozilla.org/MPL/2.0/ )
@@ -329,13 +329,17 @@ doClip(
         gridMask.topologyDifference(clipMask.constTree());
     }
 
-    typename GridType::Ptr outGrid;
+#if OPENVDB_ABI_VERSION_NUMBER <= 3
+    auto outGrid = grid.copy(CP_NEW);
+#else
+    auto outGrid = grid.copyWithNewTree();
+#endif
     {
         // Copy voxel values and states.
         tree::LeafManager<const MaskTreeT> leafNodes(gridMask);
         CopyLeafNodes<TreeT> maskOp(tree, leafNodes);
         maskOp.run();
-        outGrid = GridType::create(maskOp.tree());
+        outGrid->setTree(maskOp.tree());
     }
     {
         // Copy tile values and states.
@@ -458,7 +462,7 @@ clip(const GridType& inGrid, const math::NonlinearFrustumMap& frustumMap, bool k
     };
 
     // Construct an output grid with the same transform and metadata as the input grid.
-#ifdef OPENVDB_3_ABI_COMPATIBLE
+#if OPENVDB_ABI_VERSION_NUMBER <= 3
     auto outGrid = inGrid.copy(CP_NEW);
 #else
     auto outGrid = inGrid.copyWithNewTree();
@@ -597,6 +601,6 @@ clip(const GridType& inGrid, const math::NonlinearFrustumMap& frustumMap, bool k
 
 #endif // OPENVDB_TOOLS_CLIP_HAS_BEEN_INCLUDED
 
-// Copyright (c) 2012-2017 DreamWorks Animation LLC
+// Copyright (c) 2012-2019 DreamWorks Animation LLC
 // All rights reserved. This software is distributed under the
 // Mozilla Public License 2.0 ( http://www.mozilla.org/MPL/2.0/ )
