@@ -1,6 +1,6 @@
 ///////////////////////////////////////////////////////////////////////////
 //
-// Copyright (c) 2012-2017 DreamWorks Animation LLC
+// Copyright (c) 2012-2019 DreamWorks Animation LLC
 //
 // All rights reserved. This software is distributed under the
 // Mozilla Public License 2.0 ( http://www.mozilla.org/MPL/2.0/ )
@@ -81,6 +81,7 @@
 #include <openvdb/Grid.h>
 #include <openvdb/Types.h>
 #include <openvdb/util/NullInterrupter.h>
+#include <vector>
 
 
 namespace openvdb {
@@ -128,7 +129,7 @@ template<typename GridT, typename InterrupterT>
 class PointsToMask
 {
 public:
-    typedef typename GridT::ValueType ValueT;
+    using ValueT = typename GridT::ValueType;
 
     /// @brief Constructor from a grid and optional interrupter
     ///
@@ -150,7 +151,7 @@ public:
     {
         if (mInterrupter) mInterrupter->start("PointsToMask: adding points");
         if (grainSize > 0) {
-#ifdef OPENVDB_3_ABI_COMPATIBLE
+#if OPENVDB_ABI_VERSION_NUMBER <= 3
             typename GridT::Ptr examplar = mGrid->copy(CP_NEW);
 #else
             typename GridT::Ptr examplar = mGrid->copyWithNewTree();
@@ -188,7 +189,7 @@ private:
 
     // Private struct that implements concurrent thread-local
     // insersion of points into a grid
-    typedef tbb::enumerable_thread_specific<GridT> PoolType;
+    using PoolType = tbb::enumerable_thread_specific<GridT>;
     template<typename PointListT> struct AddPoints;
 
     // Private class that implements concurrent reduction of a thread-local pool
@@ -236,17 +237,18 @@ struct PointsToMask<GridT, InterrupterT>::AddPoints
 template<typename GridT, typename InterrupterT>
 struct PointsToMask<GridT, InterrupterT>::ReducePool
 {
-    typedef std::vector<GridT*>       VecT;
-    typedef typename VecT::iterator   IterT;
-    typedef tbb::blocked_range<IterT> RangeT;
+    using VecT = std::vector<GridT*>;
+    using IterT = typename VecT::iterator;
+    using RangeT = tbb::blocked_range<IterT>;
 
     ReducePool(PoolType& pool, GridT* grid, size_t grainSize = 1)
         : mOwnsGrid(false)
         , mGrid(grid)
     {
-        if ( grainSize == 0 ) {
-            typedef typename PoolType::const_iterator IterT;
-            for (IterT i=pool.begin(); i!=pool.end(); ++i) mGrid->topologyUnion( *i );
+        if (grainSize == 0) {
+            for (typename PoolType::const_iterator i = pool.begin(); i != pool.end(); ++i) {
+                mGrid->topologyUnion(*i);
+            }
         } else {
             VecT grids( pool.size() );
             typename PoolType::iterator i = pool.begin();
@@ -280,6 +282,6 @@ struct PointsToMask<GridT, InterrupterT>::ReducePool
 
 #endif // OPENVDB_TOOLS_POINTSTOMASK_HAS_BEEN_INCLUDED
 
-// Copyright (c) 2012-2017 DreamWorks Animation LLC
+// Copyright (c) 2012-2019 DreamWorks Animation LLC
 // All rights reserved. This software is distributed under the
 // Mozilla Public License 2.0 ( http://www.mozilla.org/MPL/2.0/ )
